@@ -309,21 +309,24 @@ cx_files_enter(void)
 void
 cx_files_tab(void)
 {
-	int compl;
+	int compl, file_type;
 
 	/* try completion first, it returns 0 on success */
 	compl = compl_file();
 
 	if (compl == -1) {
+		file_type = ppanel_file->pd->cnt ?
+		  ppanel_file->files[ppanel_file->pd->curs]->file_type : FT_NA;
 		/* -1: nothing to complete, this will be the first word */
-		if (ppanel_file->pd->cnt &&
-		  IS_FT_EXEC(ppanel_file->files[ppanel_file->pd->curs]->file_type))
+		if (IS_FT_EXEC(file_type))
 			edit_macro("./$F ");
+		else if (IS_FT_DIR(file_type))
+			edit_macro("$F/");
 		else
 			/* absolutely clueless ! */
 			win_remark("COMPLETION: please type at least the "
 			  "first character");
 	} else if (compl == -2)
 		/* -2: nothing to complete, but not in the first word */
-		cx_edit_filename();
+			edit_macro("$F ");
 }
